%define pypi_name paramiko

# disable tests, pytest-relaxed which we don't have and even
# if we would have it, it needs pytests < 3.3
%bcond_with tests

Summary:       SSH2 protocol for Python
Name:          python-%{pypi_name}
Version:       3.5.1
Release:       %mkrel 1
Url:           https://github.com/paramiko/paramiko/
License:       LGPLv2+
Group:         Development/Python
Source0:       %{pypi_source}
BuildArch:     noarch
BuildRequires: pyproject-rpm-macros
BuildRequires: pkgconfig(python3)

%description
Paramiko is a pure-Python implementation of the SSHv2 protocol, providing both
client and server functionality. It provides the foundation for the high-level
SSH library Fabric, which is what we recommend you use for common client
use-cases such as running remote shell commands or transferring files.

Direct use of Paramiko itself is only intended for users who need
advanced/low-level primitives or want to run an in-Python sshd.


%package -n python3-%{pypi_name}
Group:         Development/Python
Summary:       SSH2 protocol library for python
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
Paramiko is a pure-Python implementation of the SSHv2 protocol, providing both
client and server functionality. It provides the foundation for the high-level
SSH library Fabric, which is what we recommend you use for common client
use-cases such as running remote shell commands or transferring files.

Direct use of Paramiko itself is only intended for users who need
advanced/low-level primitives or want to run an in-Python sshd.

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files paramiko

%if %{with tests}
%check
# Remove sftp test
rm -f tests/test_sftp*.py
PYTHONPATH=%{buildroot}%{python3_sitelib} pytest-%{python3_version}
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst


%changelog
* Mon Mar 03 2025 daviddavid <daviddavid> 3.5.1-1.mga10
+ Revision: 2159082
- new version: 3.5.1
- rebuild for python 3.13

* Tue Dec 19 2023 wally <wally> 3.4.0-1.mga10
+ Revision: 2019736
- new version 3.4.0
- use pyproject rpm macros

* Wed Sep 07 2022 neoclust <neoclust> 2.11.0-1.mga9
+ Revision: 1885128
- New version  2.11.0

* Wed Mar 23 2022 ns80 <ns80> 2.7.2-4.mga9
+ Revision: 1822384
- backport upstream patch for CVE-2022-24302 (mga#30193)

* Tue Feb 15 2022 tv <tv> 2.7.2-3.mga9
+ Revision: 1775464
- Rebuild for python-3.10

* Thu Mar 18 2021 neoclust <neoclust> 2.7.2-2.mga9
+ Revision: 1704429
- Rebuild against python 3.9

* Tue Sep 08 2020 guillomovitch <guillomovitch> 2.7.2-1.mga8
+ Revision: 1623665
- new version 2.7.2

* Wed Jul 22 2020 ovitters <ovitters> 2.7.1-4.mga8
+ Revision: 1608071
- rebuild for get rid of pythonegg requires

* Wed Jul 15 2020 joequant <joequant> 2.7.1-3.mga8
+ Revision: 1606186
- rebuild

* Tue Feb 18 2020 umeabot <umeabot> 2.7.1-2.mga8
+ Revision: 1539773
- Mageia 8 Mass Rebuild

* Fri Dec 13 2019 daviddavid <daviddavid> 2.7.1-1.mga8
+ Revision: 1466124
- new version: 2.7.1

* Thu Dec 12 2019 daviddavid <daviddavid> 2.7.0-1.mga8
+ Revision: 1466056
- new version: 2.7.0

* Mon Sep 16 2019 tv <tv> 2.6.0-2.mga8
+ Revision: 1442528
- rebuild for python-3.8
- drop python2 subpkg

* Fri Jul 12 2019 daviddavid <daviddavid> 2.6.0-1.mga8
+ Revision: 1420511
- new version: 2.6.0 (mga#25094)
- rename python-paramiko to python2-paramiko

* Wed Jan 09 2019 shlomif <shlomif> 2.4.2-2.mga7
+ Revision: 1353674
- Rebuild for python3 3.7

* Tue Jan 01 2019 luigiwalser <luigiwalser> 2.4.2-1.mga7
+ Revision: 1347844
- 2.4.2

* Mon Oct 29 2018 wally <wally> 2.4.1-3.mga7
+ Revision: 1326475
- make py2 pkg to require enum34
- drop old obsoletes

* Thu Sep 20 2018 umeabot <umeabot> 2.4.1-2.mga7
+ Revision: 1289586
- Mageia 7 Mass Rebuild

* Sun Apr 22 2018 wally <wally> 2.4.1-1.mga7
+ Revision: 1220975
- new version 2.4.1

* Sun Apr 01 2018 shlomif <shlomif> 2.0.8-1.mga7
+ Revision: 1214039
- New version 2.0.8 ( MGA#22837 )

* Sun Aug 06 2017 philippem <philippem> 2.0.0-2.mga7
+ Revision: 1137703
- convert to pythonegg requires
+ pterjan <pterjan>
- Rebuild for python 3.6

* Fri May 13 2016 philippem <philippem> 2.0.0-1.mga6
+ Revision: 1014422
- update to 2.0.0

* Fri Feb 19 2016 umeabot <umeabot> 1.15.2-3.mga6
+ Revision: 971000
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 tv <tv> 1.15.2-2.mga6
+ Revision: 888946
- rebuild for python 3.5

* Tue Jan 06 2015 philippem <philippem> 1.15.2-1.mga5
+ Revision: 808729
- update to 1.15.2, add Python 3, support OpenSSH 6.7 mga#14724

* Wed Oct 15 2014 umeabot <umeabot> 1.12.4-4.mga5
+ Revision: 746527
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.12.4-3.mga5
+ Revision: 727918
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.12.4-2.mga5
+ Revision: 688202
- Mageia 5 Mass Rebuild

* Thu Jul 03 2014 philippem <philippem> 1.12.4-1.mga5
+ Revision: 642768
- Update to 1.12.4
+ pterjan <pterjan>
- Rebuild for new Python

* Fri Mar 07 2014 philippem <philippem> 1.12.2-1.mga5
+ Revision: 600907
- Update to 1.12.2

* Sat Feb 08 2014 dams <dams> 1.12.1-1.mga5
+ Revision: 585702
- new version 1.12.1

* Tue Oct 22 2013 umeabot <umeabot> 1.12.0-4.mga4
+ Revision: 543855
- Mageia 4 Mass Rebuild

* Fri Oct 18 2013 dlucio <dlucio> 1.12.0-3.mga4
+ Revision: 514827
- requieres changed since pycrypto changed its provides

* Tue Oct 15 2013 pterjan <pterjan> 1.12.0-2.mga4
+ Revision: 499077
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 05 2013 philippem <philippem> 1.12.0-1.mga4
+ Revision: 491801
- Update to 1.12.0

* Wed Jul 10 2013 philippem <philippem> 1.10.1-1.mga4
+ Revision: 452609
- Update to 1.10.1

* Sun Jan 13 2013 umeabot <umeabot> 1.7.7.1-2.mga3
+ Revision: 379224
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 17 2011 ovitters <ovitters> 1.7.7.1-1.mga2
+ Revision: 144543
- new version 1.7.7.1

* Sun Jan 23 2011 ennael <ennael> 1.7.6-2.mga1
+ Revision: 35590
- imported package python-paramiko


* Tue Nov 02 2010 Crispin Boylan <crisb@mandriva.org> 1.7.6-2mdv2011.0
+ Revision: 591781
- Rebuild

* Sun Jan 10 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.7.6-1mdv2010.1
+ Revision: 489188
- update to new version 1.7.6

* Thu Sep 17 2009 Michael Scherer <misc@mandriva.org> 1.7.5-1mdv2010.0
+ Revision: 443919
- update to new version 1.7.5

* Tue Sep 15 2009 Thierry Vignaud <tv@mandriva.org> 1.7.4-3mdv2010.0
+ Revision: 442326
- rebuild

* Mon Dec 29 2008 Crispin Boylan <crisb@mandriva.org> 1.7.4-2mdv2009.1
+ Revision: 321177
- Rebuild for 2.6

* Fri Aug 15 2008 Michael Scherer <misc@mandriva.org> 1.7.4-1mdv2009.0
+ Revision: 272310
- new version
- new url

* Mon Mar 10 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.7.2-1mdv2008.1
+ Revision: 183316
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 17 2007 Jérôme Soyer <saispo@mandriva.org> 1.6.4-1mdv2008.1
+ Revision: 122368
- New release 1.6.4 and bypass check


* Sun Jan 07 2007 Michael Scherer <misc@mandriva.org> 1.5.2-4mdv2007.0
+ Revision: 105220
- rebuild for python 2.5
- use %%rel scheme for mkrel
- Import python-paramiko

